@@ -15,12 +15,14 @@ test_that('1 rule makefile', {
                       'clean: ',
                       '\tcleanCmd',
                       'Makefile: Makefile.R',
-                      '\t$(R) -e \'{\' \\',
+                      '\t$(R) - <<\'EOFrmake\'',
+                      '\t{',
                       ifelse(getRversion() > '3.4.4',
-                             '\t-e \'    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")\' \\',
-                             '\t-e \'    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))\' \\'),
-                      '\t-e \'    source("Makefile.R")\' \\',
-                      '\t-e \'}\''))
+                             '\t    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")',
+                             '\t    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))'),
+                      '\t    source("Makefile.R")',
+                      '\t}',
+                      '\tEOFrmake'))
 })
 
 test_that('not all in makefile', {
@@ -34,12 +36,14 @@ test_that('not all in makefile', {
                       'clean: ',
                       '\tcleanCmd',
                       'Makefile: Makefile.R',
-                      '\t$(R) -e \'{\' \\',
+                      '\t$(R) - <<\'EOFrmake\'',
+                      '\t{',
                       ifelse(getRversion() > '3.4.4',
-                             '\t-e \'    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")\' \\',
-                             '\t-e \'    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))\' \\'),
-                      '\t-e \'    source("Makefile.R")\' \\',
-                      '\t-e \'}\''))
+                             '\t    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")',
+                             '\t    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))'),
+                      '\t    source("Makefile.R")',
+                      '\t}',
+                      '\tEOFrmake'))
 })
 
 test_that('not clean in makefile', {
@@ -53,12 +57,14 @@ test_that('not clean in makefile', {
                       'target.Rdata: dep1 dep2',
                       '\tbuildCmd',
                       'Makefile: Makefile.R',
-                      '\t$(R) -e \'{\' \\',
+                      '\t$(R) - <<\'EOFrmake\'',
+                      '\t{',
                       ifelse(getRversion() > '3.4.4',
-                             '\t-e \'    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")\' \\',
-                             '\t-e \'    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))\' \\'),
-                      '\t-e \'    source("Makefile.R")\' \\',
-                      '\t-e \'}\''))
+                             '\t    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")',
+                             '\t    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))'),
+                      '\t    source("Makefile.R")',
+                      '\t}',
+                      '\tEOFrmake'))
 })
 
 test_that('not Makefile in makefile', {
@@ -82,20 +88,36 @@ test_that('custom vars in makefile', {
   res <- sanitizeCovr(res)
   res <- res[seq_len(which(res == ''))]
   if (.Platform$OS.type == 'unix') {
-    expect_equal(res, c('# Generated by rmake: do not edit by hand',
+    expect_equal(res, c('# This file is generated by rmake - do not edit by hand',
+                        'ifeq ($(origin .FEATURES),undefined)',
+                        "$(error This Makefile requires GNU Make. Please install it and use 'gmake' or 'make' depending on your system)",
+                        'endif',
+                        'REQUIRED_VERSION := 3.82',
+                        'ifeq ($(filter $(REQUIRED_VERSION),$(firstword $(sort $(MAKE_VERSION) $(REQUIRED_VERSION)))),)',
+                        '$(error GNU Make $(REQUIRED_VERSION) or higher is required. You are using $(MAKE_VERSION))',
+                        'endif',
                         'SHELL=/bin/sh',
                         'R="$(R_HOME)/bin$(R_ARCH)/Rscript"',
                         'RM=rm',
                         'CP=cp',
                         'CPP=gcc',
+                        '.ONESHELL:',
                         ''))
   } else {
-    expect_equal(res, c('# Generated by rmake: do not edit by hand',
+    expect_equal(res, c('# This file is generated by rmake - do not edit by hand',
+                        'ifeq ($(origin .FEATURES),undefined)',
+                        "$(error This Makefile requires GNU Make. Please install it and use 'gmake' or 'make' depending on your system)",
+                        'endif',
+                        'REQUIRED_VERSION := 3.82',
+                        'ifeq ($(filter $(REQUIRED_VERSION),$(firstword $(sort $(MAKE_VERSION) $(REQUIRED_VERSION)))),)',
+                        '$(error GNU Make $(REQUIRED_VERSION) or higher is required. You are using $(MAKE_VERSION))',
+                        'endif',
                         'SHELL=/bin/sh',
                         'R="$(R_HOME)/bin$(R_ARCH)/Rscript"',
                         'RM=cmd //C del',
                         'CP=cmd //C copy',
                         'CPP=gcc',
+                        '.ONESHELL:',
                         ''))
   }
 })
@@ -107,20 +129,36 @@ test_that('redefined vars in makefile', {
   res <- sanitizeCovr(res)
   res <- res[seq_len(which(res == ''))]
   if (.Platform$OS.type == 'unix') {
-    expect_equal(res, c('# Generated by rmake: do not edit by hand',
+    expect_equal(res, c('# This file is generated by rmake - do not edit by hand',
+                        'ifeq ($(origin .FEATURES),undefined)',
+                        "$(error This Makefile requires GNU Make. Please install it and use 'gmake' or 'make' depending on your system)",
+                        'endif',
+                        'REQUIRED_VERSION := 3.82',
+                        'ifeq ($(filter $(REQUIRED_VERSION),$(firstword $(sort $(MAKE_VERSION) $(REQUIRED_VERSION)))),)',
+                        '$(error GNU Make $(REQUIRED_VERSION) or higher is required. You are using $(MAKE_VERSION))',
+                        'endif',
                         'SHELL=/bin/sh',
                         'R=MyR',
                         'RM=rm',
                         'CP=cp',
                         'CPP=gcc',
+                        '.ONESHELL:',
                         ''))
   } else {
-    expect_equal(res, c('# Generated by rmake: do not edit by hand',
+    expect_equal(res, c('# This file is generated by rmake - do not edit by hand',
+                        'ifeq ($(origin .FEATURES),undefined)',
+                        "$(error This Makefile requires GNU Make. Please install it and use 'gmake' or 'make' depending on your system)",
+                        'endif',
+                        'REQUIRED_VERSION := 3.82',
+                        'ifeq ($(filter $(REQUIRED_VERSION),$(firstword $(sort $(MAKE_VERSION) $(REQUIRED_VERSION)))),)',
+                        '$(error GNU Make $(REQUIRED_VERSION) or higher is required. You are using $(MAKE_VERSION))',
+                        'endif',
                         'SHELL=/bin/sh',
                         'R=MyR',
                         'RM=cmd //C del',
                         'CP=cmd //C copy',
                         'CPP=gcc',
+                        '.ONESHELL:',
                         ''))
   }
 })
@@ -142,12 +180,14 @@ test_that('multiple target rule makefile', {
                       'clean: ',
                       '\tcleanCmd',
                       'Makefile: Makefile.R',
-                      '\t$(R) -e \'{\' \\',
+                      '\t$(R) - <<\'EOFrmake\'',
+                      '\t{',
                       ifelse(getRversion() > '3.4.4',
-                             '\t-e \'    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")\' \\',
-                             '\t-e \'    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))\' \\'),
-                      '\t-e \'    source("Makefile.R")\' \\',
-                      '\t-e \'}\''))
+                             '\t    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")',
+                             '\t    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))'),
+                      '\t    source("Makefile.R")',
+                      '\t}',
+                      '\tEOFrmake'))
 })
 
 test_that('makefile with tasks', {
@@ -195,12 +235,14 @@ test_that('makefile with tasks', {
                       'clean_task2: ',
                       '\tcleanCmd2',
                       'Makefile: Makefile.R',
-                      '\t$(R) -e \'{\' \\',
+                      '\t$(R) - <<\'EOFrmake\'',
+                      '\t{',
                       ifelse(getRversion() > '3.4.4',
-                             '\t-e \'    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")\' \\',
-                             '\t-e \'    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))\' \\'),
-                      '\t-e \'    source("Makefile.R")\' \\',
-                      '\t-e \'}\''))
+                             '\t    params <- list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\")',
+                             '\t    params <- structure(list(.target = \"Makefile\", .script = \"Makefile.R\", .depends = NULL, .task = \"all\"), .Names = c(\".target\", \".script\", \".depends\", \".task\"))'),
+                      '\t    source("Makefile.R")',
+                      '\t}',
+                      '\tEOFrmake'))
 })
 
 
